@@ -12,9 +12,11 @@ from .connection import Connection
 
 class Kola(kola.Kola, TCPServer):
     def __init__(self, conn_class=None, *args, **kwargs):
-        kola.Kola.__init__(self, conn_class or Connection)
+        kola.Kola.__init__(self)
         TCPServer.__init__(self, *args, **kwargs)
 
+        self.conn_class = conn_class or Connection
+
         self.repeat_timer_func_list = []
         self._configure_exc_handler()
 
